/*******************************************************************************
 *
 * Copyright (c) 2016-2026 HYCON Technology, Inc.
 * All rights reserved.
 * HYCON Technology <www.hycontek.com>
 *
 * HYCON reserves the right to amend this code without notice at any time.
 * HYCON assumes no responsibility for any errors appeared in the code,
 * and HYCON disclaims any express or implied warranty, relating to sale
 * and/or use of this code including liability or warranties relating
 * to fitness for a particular purpose, or infringement of any patent,
 * copyright or other intellectual property right.
 *
 * -----------------------------------------------------------------------------
 * Project Name : HY16F3981_Power
 * IDE tooling  : AndeSight C/C++ IDE, version: 2.1.1 Build ID : 201608241332
 * Device Ver.  : HY16F_RDSp3_DeviceV0.2 crt0.o for HY16F3981 MCU.
 * Library Ver. : 0.2
 * MCU Device   :
 * Description  :
 * Created Date : 2018/3/9
 * Created by   : Robert.Wang
 *
 * Program Description:
 * --------------------
 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include "DrvCLOCK.h"
#include "Display.h"
#include "my define.h"
#include "HY16F3981.h"
#include "DrvPMU.h"
#include "System.h"
#include "DrvGPIO.h"

/*----------------------------------------------------------------------------*/
/* STRUCTURES                                                                 */
/*----------------------------------------------------------------------------*/
typedef union _PTINTSTATUS
{
  char  _byte;
  struct
  {
    unsigned b_PTINT0done:1;
    unsigned b_PTINT1done:1;
    unsigned b_PTINT2done:1;
    unsigned b_PTINT3done:1;
    unsigned b_PTINT4done:1;
    unsigned b_PTINT5done:1;
    unsigned b_PTINT6Done:1;
    unsigned b_PTINT7Done:1;
  };
} PTINTSTATUS;

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define KEY_PORT E_PT3
#define KEYIN0 BIT0
#define KEYIN1 BIT5

//#define IDLE_MODE
#define SLEEP_MODE
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
PTINTSTATUS  PT3INTSTATUSbits;
unsigned int PT30_IDF;
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num);

/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
int main(void)
{
  DisplayInit();
  ClearLCDframe();
  DrvGPIO_ClkGenerator(E_HS_CK,1);                      //Set IO sampling clock input source is E_HS_CK
  DrvGPIO_Open(KEY_PORT,KEYIN1|KEYIN0,E_IO_INPUT);      //set PT3.0/PT3.5 INPUT
  DrvGPIO_Open(KEY_PORT,KEYIN1|KEYIN0,E_IO_PullHigh);   //enable PT3.0/PT3.5 pull high R
  DrvGPIO_Open(KEY_PORT,KEYIN1|KEYIN0,E_IO_IntEnable);  //PT3.0/PT3.5 interrupt enable
  DrvGPIO_IntTrigger(KEY_PORT,KEYIN1|KEYIN0,E_N_Edge);  //PT3.0/PT3.5 interrupt trigger method is negative edge
  DrvGPIO_ClearIntFlag(KEY_PORT,KEYIN1|KEYIN0);         //clear PT3 interrupt flag
  PT3INTSTATUSbits._byte = 0;
  SYS_EnableGIE(4,0x3FF);                               //Enable GIE(Global Interrupt)

  while(1)
  {
    if(PT3INTSTATUSbits.b_PTINT0done)                   //if PT3.0 low, wake up
    {
      LCD_DATA_DISPLAY(50000);
      PT3INTSTATUSbits.b_PTINT0done=0;
    }

    if(PT3INTSTATUSbits.b_PTINT5done)                   //if PT3.5 low, Enter Sleep or Idle Mode
    {

      PT30_IDF=DrvGPIO_PortIDIF(E_PT3) & 0x01;          //check wake up pin, PT3.0 IDF status
      if(PT30_IDF==0x01)
      {
      //Enter Sleep or Idle Mode setting
      DrvLCD_VLCDMode(E_VLCD_DISABLE);
      while((inw(0x41B00)&(1<<IDF))==0);                //Wait LCD Idle, IDF=20
      DrvPMU_LDO_LowPower(1);                           //SET low power mode
      DrvCLOCK_SelectMCUClock(E_LS_CK,1);               //SET CPUCKL=LPO/2
      DrvCLOCK_CloseIHOSC();                            //Close HAO
      #if defined(IDLE_MODE)
      SYS_LowPower(1);                                  //Idle Mode, around 3.5uA
      #endif
      #if defined(SLEEP_MODE)
      SYS_LowPower(0);                                  //sleep mode, around 2.5uA
      #endif
      }
      //If wake up from Sleep or Idle mode, user can enable internal HAO first to do some application
      DrvPMU_LDO_LowPower(0);                           //SET normal power mode
      DrvCLOCK_EnableHighOSC(E_INTERNAL,1);
      DrvCLOCK_SelectMCUClock(E_HS_CK,0);               //SET CPUCKL=HAO/1
      DrvGPIO_ClkGenerator(E_HS_CK,1);                  //Set IO sampling clock input source is E_HS_CK
      DisplayInit();
      PT3INTSTATUSbits.b_PTINT5done=0;
    }
  }

  return 0;
}

/*----------------------------------------------------------------------------*/
/* Function Name: HW0_ISR()                                                   */
/* Description  : I2C/UART/SPI interrupt Service Routine (HW0).               */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW0_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW1_ISR()                                                   */
/* Description  : WDT & RTC & Timer A/B/C interrupt Service Routine (HW1).    */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW1_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW2_ISR()                                                   */
/* Description  : ADC interrupt Service Routine (HW2).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW2_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW4_ISR()                                                   */
/* Description  : PT3 interrupt Service Routine (HW4).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW4_ISR(void)
{

  uint32_t PORT_IntFlag;

  PORT_IntFlag=DrvGPIO_GetIntFlag(KEY_PORT);
  if((PORT_IntFlag&KEYIN0)==KEYIN0)
  {
    PT3INTSTATUSbits.b_PTINT0done=1;
  }
    if((PORT_IntFlag&KEYIN1)==KEYIN1)
  {
    PT3INTSTATUSbits.b_PTINT5done=1;
  }
  DrvGPIO_ClearIntFlag(KEY_PORT,KEYIN1|KEYIN0);         //clear PT3.0/PT3.5 interrupt flag

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW5_ISR()                                                   */
/* Description  : PT2 interrupt Service Routine (HW5).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW5_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW7_ISR()                                                   */
/* Description  : UART2 interrupt Service Routine (HW7).                      */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW7_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW8_ISR()                                                   */
/* Description  : TMB2 interrupt Service Routine (HW8).                       */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW8_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW9_ISR()                                                   */
/* Description  : OPA interrupt Service Routine (HW9).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW9_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: tlb_exception_handler()                                     */
/* Description  : Exception Service Routines.                                 */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void tlb_exception_handler()
{
  asm("nop");  //procedure define by customer.
  asm("nop");
}
/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
  for(;num>0;num--)
  asm("NOP");
}
/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
