/*******************************************************************************
 *
 * Copyright (c) 2016-2026 HYCON Technology, Inc.
 * All rights reserved.
 * HYCON Technology <www.hycontek.com>
 *
 * HYCON reserves the right to amend this code without notice at any time.
 * HYCON assumes no responsibility for any errors appeared in the code,
 * and HYCON disclaims any express or implied warranty, relating to sale
 * and/or use of this code including liability or warranties relating
 * to fitness for a particular purpose, or infringement of any patent,
 * copyright or other intellectual property right.
 *
 * -----------------------------------------------------------------------------
 * Project Name : HY16F3981_RTC
 * IDE tooling  : AndeSight C/C++ IDE, version: 2.1.1 Build ID : 201608241332
 * Device Ver.  : HY16F_RDSp3_DeviceV0.2 crt0.o for HY16F3981 MCU.
 * Library Ver. : 0.2
 * MCU Device   :
 * Description  : HY16F3981 display the RTC_counter or TimerDtata on LCD by #define RTC_counter_show or TimerDtata_show
 * Created Date : 2018/3/9
 * Created by   : Robert.Wang
 *
 * Program Description:
 * --------------------
 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include "DrvCLOCK.h"
#include "Display.h"
#include "my define.h"
#include "HY16F3981.h"
#include "DrvRTC.h"
#include "DrvLCD.h"
#include "Display.h"
#include "System.h"
/*----------------------------------------------------------------------------*/
/* STRUCTURES                                                                 */
/*----------------------------------------------------------------------------*/
volatile typedef union _MCUSTATUS
{
  char  _byte;
  struct
  {
    unsigned b_ADCdone:1;
    unsigned b_TMAdone:1;
    unsigned b_TMBdone:1;
    unsigned b_TMC0done:1;
    unsigned b_TMC1done:1;
    unsigned b_RTCdone:1;
    unsigned b_UART_TxDone:1;
    unsigned b_UART_RxDone:1;
  };
} MCUSTATUS;

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
//#define  RTC_counter_show
#define  TimerDtata_show

/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
MCUSTATUS  MCUSTATUSbits;

unsigned int sec,min,hour,week,day,month,year ;
unsigned int RTC_counter;
unsigned int TimerDtata;
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num);
void InitalRTC(void);
int ComputeWeek(int TempYear, int TempMonth, int TempDay);

/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
int main(void)
{

  S_DRVRTC_TIME_DATA_T sCurTime;    //Setting Start
  RTC_counter=0;
  TimerDtata=0;

  DisplayInit();
  ClearLCDframe();
  InitalRTC();
  MCUSTATUSbits._byte = 0;
  SYS_EnableGIE(4,0x3FF);           //Enable GIE(Global Interrupt)

  while(1)
  {
    if(MCUSTATUSbits.b_RTCdone==1)
    {
      DrvRTC_Read(DRVRTC_CURRENT_TIME,&sCurTime);
      TimerDtata=sCurTime.u32cSecond+sCurTime.u32cMinute*100+sCurTime.u32cHour*10000;
#if defined(TimerDtata_show)
	  LCD_DATA_DISPLAY(TimerDtata);
#endif
#if defined(RTC_counter_show)
	  LCD_DATA_DISPLAY(RTC_counter);
#endif

      sec=sCurTime.u32cSecond;
      min=sCurTime.u32cMinute;
      hour=sCurTime.u32cHour;
      week=sCurTime.u32cDayOfWeek;
      day=sCurTime.u32cDay;
      month=sCurTime.u32cMonth;
      year=sCurTime.u32Year;
      MCUSTATUSbits.b_RTCdone=0;
      }
  }

  return 0;
}

/*----------------------------------------------------------------------------*/
/* Function Name: HW0_ISR()                                                   */
/* Description  : I2C/UART/SPI interrupt Service Routine (HW0).               */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW0_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW1_ISR()                                                   */
/* Description  : WDT & RTC & Timer A/B/C interrupt Service Routine (HW1).    */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW1_ISR(void)
{
  if(DrvRTC_ReadState()&&0x2)       //check PTF flag
  {
    DrvRTC_ClearState(E_DRVRTC_CLEAR_ALL);
    DrvRTC_ClearIntFlag();
    RTC_counter++;
    MCUSTATUSbits.b_RTCdone=1;
  }
}
/*----------------------------------------------------------------------------*/
/* Function Name: HW2_ISR()                                                   */
/* Description  : ADC interrupt Service Routine (HW2).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW2_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW4_ISR()                                                   */
/* Description  : PT3 interrupt Service Routine (HW4).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW4_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW5_ISR()                                                   */
/* Description  : PT2 interrupt Service Routine (HW5).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW5_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW7_ISR()                                                   */
/* Description  : UART2 interrupt Service Routine (HW7).                      */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW7_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW8_ISR()                                                   */
/* Description  : TMB2 interrupt Service Routine (HW8).                       */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW8_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW9_ISR()                                                   */
/* Description  : OPA interrupt Service Routine (HW9).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW9_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: tlb_exception_handler()                                     */
/* Description  : Exception Service Routines.                                 */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void tlb_exception_handler()
{
  asm("nop");  //procedure define by customer.
  asm("nop");
}
/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
  for(;num>0;num--)
  asm("NOP");
}


/*----------------------------------------------------------------------------*/
/* Function Name: InitalRTC()                                                 */
/* Description  : RTC Initialization Subroutines.                             */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void InitalRTC()
{
  S_DRVRTC_TIME_DATA_T sCurTime;        //Setting Start
  DrvCLOCK_EnableLowOSC(E_EXTERNAL,130000);
  DrvRTC_ClkConfig(2);                  //Set 0x40308 RTCKS=10b, LSXT

  //DRVRTC_CURRENT_TIME or Alarm Time
  DrvRTC_WriteEnable();
  DrvRTC_Read(DRVRTC_CURRENT_TIME,&sCurTime);
  sCurTime.u8cClockDisplay=0;           //DRVRTC_CLOCK_12//DRVRTC_CLOCK_24
  sCurTime.u8cAmPm=0;                   //DRVRTC_AM//DRVRTC_PM
  sCurTime.u32cSecond=40;
  sCurTime.u32cMinute=59;
  sCurTime.u32cHour=23;
  sCurTime.u32cDay=18;
  sCurTime.u32cMonth=2;
  sCurTime.u32Year=2018;
  sCurTime.u32cDayOfWeek=ComputeWeek(sCurTime.u32Year,sCurTime.u32cMonth,sCurTime.u32cDay);
  sCurTime.u8IsEnableWakeUp=0;          //WK
  DrvRTC_Write(DRVRTC_CURRENT_TIME,&sCurTime);
  DrvRTC_HourFormat(E_DRVRTC_HOUR_24);  //1:12hour 0:24hour
  DrvRTC_Enable();
  DrvRTC_PeriodicTimeEnable(E_DRVRTC_1_8_SEC);
  DrvRTC_ClearIntFlag();
  DrvRTC_EnableInt();                   //Enable RTC interrupt
}

/*----------------------------------------------------------------------------*/
/* Compute Week Subroutines                                                   */
/*----------------------------------------------------------------------------*/
int ComputeWeek(int TempYear, int TempMonth, int TempDay)
{
  int TempWeek;
  if (TempMonth >= 3)
  {
    TempMonth = TempMonth - 2;
  }
  else
  {
    TempMonth = TempMonth + 10;
    TempYear--;
  }

  TempWeek = TempYear + (int)(TempYear / 4) - (int)(TempYear / 100) +(int)(TempYear / 400) + (int)(2.6 * TempMonth - 0.2) + TempDay;
  TempWeek = TempWeek - 7*(int)(TempWeek / 7);
  return (TempWeek);
}
/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
