/*******************************************************************************
 *
 * Copyright (c) 2016-2026 HYCON Technology, Inc.
 * All rights reserved.
 * HYCON Technology <www.hycontek.com>
 *
 * HYCON reserves the right to amend this code without notice at any time.
 * HYCON assumes no responsibility for any errors appeared in the code,
 * and HYCON disclaims any express or implied warranty, relating to sale
 * and/or use of this code including liability or warranties relating
 * to fitness for a particular purpose, or infringement of any patent,
 * copyright or other intellectual property right.
 *
 * -----------------------------------------------------------------------------
 * Project Name : HY16F3981_SPI
 * IDE tooling  : AndeSight C/C++ IDE, version: 2.1.1 Build ID : 201608241332
 * Device Ver.  : HY16F_RDSp3_DeviceV0.2 crt0.o for HY16F3981 MCU.
 * Library Ver. : 0.2
 * MCU Device   :
 * Description  : HY16F3981 use SPI interface to communicate with SPI Flash(W25X40)
 * Created Date : 2018/3/9
 * Created by   : Robert.Wang
 *
 * Program Description:
 * --------------------
 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include "DrvREG32.h"
#include "SpecialMacro.h"
#include "stdint.h"
#include "HY16F3981.h"
#include "Display.h"
#include "System.h"
#include "DrvGPIO.h"
#include "my define.h"
#include "SPI_Flash.h"

/*----------------------------------------------------------------------------*/
/* STRUCTURES                                                                 */
/*----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define FlashAddress 0x000000

/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char Flash_Write_Buffer[256];
unsigned char Flash_Read_Buffer[256];
unsigned short Flash_ID;
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num);

/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
int main(void)
{

  const unsigned char String1[]={
  "Hycon Technology was established in July, 2007 in Taipei, Taiwan. We dedicate ourselves to develop high precision and low drift analog signal related processing ICs." };
  const unsigned char String2[]={
  "The identity stands for the vision and values of Hycon Technology- To be the ideal solution partner in the area of analog circuit." };
  unsigned short index_d,Size;

  InitalSPI();
  DisplayInit();
  ClearLCDframe();
  Delay(10000);
  DisplayHYcon();
  Delay(10000);

  Flash_ID=SpiFlash_ReadMidDid();                              //If correct, Flash_ID=0xEF12

  //Test1 : 16F3981 write String1 to Flash, and Read out
  Size=sizeof(String1);
  SpiFlash_ChipErase();                                        //Erase DATA
  Delay(256);
  SpiFlash_ReadData(Flash_Read_Buffer,FlashAddress,Size);      //Read DATA
  Delay(256);

  for( index_d=0;index_d<Size;index_d++)
  {
    Flash_Write_Buffer[index_d]=String1[index_d];
  }
  SpiFlash_PageProgram(Flash_Write_Buffer,FlashAddress,Size);  //Write DATA
  Delay(256);
  SpiFlash_ReadData(Flash_Read_Buffer,FlashAddress,Size);      //Read DATA
  Delay(256);

  for( index_d=0;index_d<Size;index_d++)
  {
    if(Flash_Read_Buffer[index_d]!=String1[index_d])
    {
      LCD_DATA_DISPLAY(1);                                     //If error, LCD Display "1"
      while(1);
    }
    else
      LCD_DATA_DISPLAY(0);                                     //If correct, LCD Display "0"
    }

  //Test2 : 16F3981 write String2 to Flash, and Read out
  Size=sizeof(String2);
  SpiFlash_SectorErase(0x00);                                  //Erase DATA
  Delay(256);
  SpiFlash_ReadData(Flash_Read_Buffer,FlashAddress,Size);      //Read DATA
  Delay(256);

  for( index_d=0;index_d<Size;index_d++)
  {
    Flash_Write_Buffer[index_d]=String2[index_d];
  }
  SpiFlash_PageProgram(Flash_Write_Buffer,FlashAddress,Size);  //Write DATA
  Delay(256);
  SpiFlash_ReadData(Flash_Read_Buffer,FlashAddress,Size);      //Read DATA
  Delay(256);

  for( index_d=0;index_d<Size;index_d++)
  {
    if(Flash_Read_Buffer[index_d]!=String2[index_d])
    {
      LCD_DATA_DISPLAY(1);                                     //If error, LCD Display "1"
      while(1);
    }
    else
      LCD_DATA_DISPLAY(123);                                   //If correct, LCD Display "123"
    }

  while(1);

  return 0;

}

/*----------------------------------------------------------------------------*/
/* Function Name: HW0_ISR()                                                   */
/* Description  : I2C/UART/SPI interrupt Service Routine (HW0).               */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW0_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW1_ISR()                                                   */
/* Description  : WDT & RTC & Timer A/B/C interrupt Service Routine (HW1).    */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW1_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW2_ISR()                                                   */
/* Description  : ADC interrupt Service Routine (HW2).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW2_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW4_ISR()                                                   */
/* Description  : PT3 interrupt Service Routine (HW4).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW4_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW5_ISR()                                                   */
/* Description  : PT2 interrupt Service Routine (HW5).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW5_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW7_ISR()                                                   */
/* Description  : UART2 interrupt Service Routine (HW7).                      */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW7_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW8_ISR()                                                   */
/* Description  : TMB2 interrupt Service Routine (HW8).                       */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW8_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW9_ISR()                                                   */
/* Description  : OPA interrupt Service Routine (HW9).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW9_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: tlb_exception_handler()                                     */
/* Description  : Exception Service Routines.                                 */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void tlb_exception_handler()
{
  asm("nop");  //procedure define by customer.
  asm("nop");
}
/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
  for(;num>0;num--)
  asm("NOP");
}
/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
