/*******************************************************************************
 *
 * Copyright (c) 2016-2026 HYCON Technology, Inc.
 * All rights reserved.
 * HYCON Technology <www.hycontek.com>
 *
 * HYCON reserves the right to amend this code without notice at any time.
 * HYCON assumes no responsibility for any errors appeared in the code,
 * and HYCON disclaims any express or implied warranty, relating to sale
 * and/or use of this code including liability or warranties relating
 * to fitness for a particular purpose, or infringement of any patent,
 * copyright or other intellectual property right.
 *
 * -----------------------------------------------------------------------------
 * Project Name : HY16F3981_WDT_Reset
 * IDE tooling  : AndeSight C/C++ IDE, version: 2.1.1 Build ID : 201608241332
 * Device Ver.  : HY16F_RDSp3_DeviceV0.2 crt0.o for HY16F3981 MCU.
 * Library Ver. : 0.2
 * MCU Device   :
 * Description  : HY16F3981 WDT Reset occur on WDT_count near to 2500~3400, it depends on the HAO frequency setting
 * After WDT_Reset, if PT3.0=Low. Set WDT_count=0, WDT re-count again, start from 0 to count
 * Created Date : 2018/3/9
 * Created by   : Robert.Wang
 *
 * Program Description:
 * --------------------
 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include "DrvCLOCK.h"
#include "Display.h"
#include "my define.h"
#include "HY16F3981.h"
#include "Display.h"
#include "System.h"
#include "DrvGPIO.h"
#include "DrvTimer.h"
/*----------------------------------------------------------------------------*/
/* STRUCTURES                                                                 */
/*----------------------------------------------------------------------------*/
volatile typedef union _MCUSTATUS
{
  char  _byte;
  struct
  {
    unsigned b_ADCdone:1;
    unsigned b_TMAdone:1;
    unsigned b_TMBdone:1;
    unsigned b_TMC0done:1;
    unsigned b_WDTdone:1;
    unsigned b_RTCdone:1;
    unsigned b_UART_TxDone:1;
    unsigned b_UART_RxDone:1;
  };
} MCUSTATUS;


typedef union _PTINTSTATUS
{
  char  _byte;
  struct
  {
    unsigned b_PTINT0done:1;
    unsigned b_PTINT1done:1;
    unsigned b_PTINT2done:1;
    unsigned b_PTINT3done:1;
    unsigned b_PTINT4done:1;
    unsigned b_PTINT5done:1;
    unsigned b_PTINT6Done:1;
    unsigned b_PTINT7Done:1;
  };
} PTINTSTATUS;

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define KEY_PORT E_PT3
#define KEYIN0 BIT0


/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
MCUSTATUS  MCUSTATUSbits;
PTINTSTATUS  PT3INTSTATUSbits;
unsigned int WDT_count;

/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num);

/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
int main(void)
{
  WDT_count=0;
  DisplayInit();
  ClearLCDframe();

  DrvWDT_Open(E_NMI,E_PRE_SCALER_D2048);         //WDT IRQ open pre scaler 2048
  DrvWDT_ClearWDT();                             //Clear WDT_count
  DrvWDT_ResetEnable();                          //set WDNMI=1. 0x40108[6]=1b

  DrvGPIO_ClkGenerator(E_HS_CK,1);               //Set IO sampling clock input source is HS_CK
  DrvGPIO_Open(KEY_PORT,KEYIN0,E_IO_INPUT);      //set PT3.0 INPUT
  DrvGPIO_Open(KEY_PORT,KEYIN0,E_IO_PullHigh);   //enable PT3.0 pull high R
  DrvGPIO_Open(KEY_PORT,KEYIN0,E_IO_IntEnable);  //PT3.0 interrupt enable
  DrvGPIO_IntTrigger(KEY_PORT,KEYIN0,E_N_Edge);  //PT3.0 interrupt trigger method is negative edge
  DrvGPIO_ClearIntFlag(KEY_PORT,KEYIN0);         //clear PT3 interrupt flag

  PT3INTSTATUSbits._byte = 0;
  MCUSTATUSbits._byte = 0;
  SYS_EnableGIE(4,0x3FF);                        //Enable GIE(Global Interrupt)

  while(1)
  {
    for(WDT_count=0;WDT_count<999999;WDT_count++)
    {
      LCD_DATA_DISPLAY(WDT_count);               //WDT Reset occur on WDT_count=2500~3400, it depends on the HAO frequency
      Delay(1000);
      if(PT3INTSTATUSbits.b_PTINT0done)          //if PT3.0 low
      {
        WDT_count=0;                             //Set WDT_count=0,
        DrvWDT_ClearWDT();                       //WDT re-count again, start from 0 to count
        PT3INTSTATUSbits.b_PTINT0done=0;
      }
    }
  }

  return 0;
}

/*----------------------------------------------------------------------------*/
/* Function Name: HW0_ISR()                                                   */
/* Description  : I2C/UART/SPI interrupt Service Routine (HW0).               */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW0_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW1_ISR()                                                   */
/* Description  : WDT & RTC & Timer A/B/C interrupt Service Routine (HW1).    */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW1_ISR(void)
{
  if(DrvTIMER_GetIntFlag(E_WDT))
  {
    MCUSTATUSbits.b_WDTdone=1;
    DrvTIMER_ClearIntFlag(E_WDT);         //Clear WDT interrupt flag
  }
}
/*----------------------------------------------------------------------------*/
/* Function Name: HW2_ISR()                                                   */
/* Description  : ADC interrupt Service Routine (HW2).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW2_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW4_ISR()                                                   */
/* Description  : PT3 interrupt Service Routine (HW4).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW4_ISR(void)
{
  uint32_t PORT_IntFlag;

  PORT_IntFlag=DrvGPIO_GetIntFlag(KEY_PORT);
  if((PORT_IntFlag&KEYIN0)==KEYIN0)
  {
    PT3INTSTATUSbits.b_PTINT0done=1;
  }
  DrvGPIO_ClearIntFlag(KEY_PORT,KEYIN0);  //clear PT3.0 interrupt flag

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW5_ISR()                                                   */
/* Description  : PT2 interrupt Service Routine (HW5).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW5_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW7_ISR()                                                   */
/* Description  : UART2 interrupt Service Routine (HW7).                      */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW7_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW8_ISR()                                                   */
/* Description  : TMB2 interrupt Service Routine (HW8).                       */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW8_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW9_ISR()                                                   */
/* Description  : OPA interrupt Service Routine (HW9).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW9_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: tlb_exception_handler()                                     */
/* Description  : Exception Service Routines.                                 */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void tlb_exception_handler()
{
  asm("nop");  //procedure define by customer.
  asm("nop");
}
/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
  for(;num>0;num--)
  asm("NOP");
}
/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
